Documentation
¶
Index ¶
- func NewCmdCost(streams genericclioptions.IOStreams, GitCommit string, GitBranch string, ...) *cobra.Command
- func NewCmdPredict(streams genericclioptions.IOStreams) *cobra.Command
- type AggregatedAllocationOptions
- type CostOptions
- type CostOptionsLabel
- type CostOptionsNode
- type CostOptionsTUI
- type PredictOptions
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func NewCmdCost ¶
func NewCmdCost( streams genericclioptions.IOStreams, GitCommit string, GitBranch string, GitState string, GitSummary string, BuildDate string, ) *cobra.Command
NewCmdCost provides a cobra command that acts as a parent command for all subcommands. It provides only basic usage information. See common.go and the subcommands for the actual functionality.
func NewCmdPredict ¶ added in v0.5.0
func NewCmdPredict( streams genericclioptions.IOStreams, ) *cobra.Command
Types ¶
type AggregatedAllocationOptions ¶ added in v0.5.0
type AggregatedAllocationOptions struct {
CostOptions
display.AllocationDisplayOptions
}
type CostOptions ¶
type CostOptions struct {
query.QueryBackendOptions
// contains filtered or unexported fields
}
CostOptions holds common options for querying and displaying data from the kubecost API
func (*CostOptions) Validate ¶
func (co *CostOptions) Validate() error
type CostOptionsLabel ¶
type CostOptionsLabel struct {
CostOptions
display.AllocationDisplayOptions
// contains filtered or unexported fields
}
CostOptionsLabel contains the standard CostOptions and any options specific to label queries.
type CostOptionsNode ¶ added in v0.2.4
type CostOptionsNode struct {
CostOptions
display.AssetDisplayOptions
}
CostOptionsNode contains the standard CostOptions and any options specific to node queries.
type CostOptionsTUI ¶ added in v0.2.7
type CostOptionsTUI struct {
query.QueryBackendOptions
// contains filtered or unexported fields
}
type PredictOptions ¶ added in v0.3.0
type PredictOptions struct {
query.QueryBackendOptions
display.PredictDisplayOptions
// contains filtered or unexported fields
}
PredictOptions contains options specific to prediction queries.
func (*PredictOptions) Complete ¶ added in v0.3.0
func (predictO *PredictOptions) Complete(restConfig *rest.Config) error
func (*PredictOptions) Validate ¶ added in v0.3.0
func (predictO *PredictOptions) Validate() error
Source Files
¶
Click to show internal directories.
Click to hide internal directories.